@@ -20,7 +20,8 @@ class BrickCommandHandler:
         if self.command_line_arguments.command == CREATE_COMMAND:
             create.create(brick_name=self.command_line_arguments.name,
                           set_as_input=self.command_line_arguments.set_as_input,
-                          template_folder=template_folder
+                          template_folder=template_folder,
+                          template=self.command_line_arguments.from_template
                           )
         if self.command_line_arguments.command == INITIALIZE_COMMAND:
             create.initialize(brick_name=self.command_line_arguments.name,
